# Welcome to brainsig

|        |        |
|--------|--------|
| Package | [![Latest PyPI Version](https://img.shields.io/pypi/v/brainsig.svg)](https://pypi.org/project/brainsig/) [![Supported Python Versions](https://img.shields.io/pypi/pyversions/brainsig.svg)](https://pypi.org/project/brainsig/) [![Documentation](https://readthedocs.org/projects/brainsig/badge/?version=latest)](https://brainsig.readthedocs.io/en/latest/?badge=latest) |
| Meta   | [![Code of Conduct](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](CODE_OF_CONDUCT.md) |

*TODO: the above badges that indicate python version and package version will only work if your package is on PyPI.
If you don't plan to publish to PyPI, you can remove them.*

brainsig is a project that (describe what it does here).

## Get started

You can install this package into your preferred Python environment using pip:

```bash
$ pip install brainsig
```

TODO: Add a brief example of how to use the package to this section

To use brainsig in your code:

```python
>>> import brainsig
>>> brainsig.hello_world()
```

## Copyright

- Copyright © 2025 Tony Barrows.
- Free software distributed under the [MIT License](./LICENSE).
